from cdnmon.model.cdn import BGPViewCIDR
from cdnmon.model.cdn import CNAMEPattern
from cdnmon.model.cdn import CommonCDN

CDN = CommonCDN(
    name="alibaba-cdn",
    asn_patterns=["alibaba", "taobao", "alicloud"],
    cname_suffixes=[
        CNAMEPattern(suffix=".cdngslb.com", pattern=r"${domain}.cdngslb.com"),
        CNAMEPattern(suffix=".queniuaa.com", pattern=r"${domain}.queniuaa.com"),
        CNAMEPattern(suffix=".queniuab.com", pattern=r"${domain}.queniuab.com"),
        CNAMEPattern(suffix=".queniuai.com", pattern=r"${domain}.queniuai.com"),
        CNAMEPattern(suffix=".queniuak.com", pattern=r"${domain}.queniuak.com"),
        CNAMEPattern(suffix=".queniual.com", pattern=r"${domain}.queniual.com"),
        CNAMEPattern(suffix=".queniuam.com", pattern=r"${domain}.queniuam.com"),
        CNAMEPattern(suffix=".queniubd.com", pattern=r"${domain}.queniubd.com"),
        CNAMEPattern(suffix=".queniubg.com", pattern=r"${domain}.queniubg.com"),
        CNAMEPattern(suffix=".queniubh.com", pattern=r"${domain}.queniubh.com"),
        CNAMEPattern(suffix=".queniubk.com", pattern=r"${domain}.queniubk.com"),
        CNAMEPattern(suffix=".queniubl.com", pattern=r"${domain}.queniubl.com"),
        CNAMEPattern(suffix=".queniubm.com", pattern=r"${domain}.queniubm.com"),
        CNAMEPattern(suffix=".queniubn.com", pattern=r"${domain}.queniubn.com"),
        CNAMEPattern(suffix=".queniucdn.com", pattern=r"${domain}.queniucdn.com"),
        CNAMEPattern(suffix=".queniucf.com", pattern=r"${domain}.queniucf.com"),
        CNAMEPattern(suffix=".queniucg.com", pattern=r"${domain}.queniucg.com"),
        CNAMEPattern(suffix=".queniuck.com", pattern=r"${domain}.queniuck.com"),
        CNAMEPattern(suffix=".queniucl.com", pattern=r"${domain}.queniucl.com"),
        CNAMEPattern(suffix=".queniucm.com", pattern=r"${domain}.queniucm.com"),
        CNAMEPattern(suffix=".queniucn.com", pattern=r"${domain}.queniucn.com"),
        CNAMEPattern(suffix=".queniuco.com", pattern=r"${domain}.queniuco.com"),
        CNAMEPattern(suffix=".queniucs.com", pattern=r"${domain}.queniucs.com"),
        CNAMEPattern(suffix=".queniucx.com", pattern=r"${domain}.queniucx.com"),
        CNAMEPattern(suffix=".queniucz.com", pattern=r"${domain}.queniucz.com"),
        CNAMEPattern(suffix=".queniuda.com", pattern=r"${domain}.queniuda.com"),
        CNAMEPattern(suffix=".queniudd.com", pattern=r"${domain}.queniudd.com"),
        CNAMEPattern(suffix=".queniudg.com", pattern=r"${domain}.queniudg.com"),
        CNAMEPattern(suffix=".queniudl.com", pattern=r"${domain}.queniudl.com"),
        CNAMEPattern(suffix=".queniudns.com", pattern=r"${domain}.queniudns.com"),
        CNAMEPattern(suffix=".queniudo.com", pattern=r"${domain}.queniudo.com"),
        CNAMEPattern(suffix=".queniudt.com", pattern=r"${domain}.queniudt.com"),
        CNAMEPattern(suffix=".queniuee.com", pattern=r"${domain}.queniuee.com"),
        CNAMEPattern(suffix=".queniueg.com", pattern=r"${domain}.queniueg.com"),
        CNAMEPattern(suffix=".queniueh.com", pattern=r"${domain}.queniueh.com"),
        CNAMEPattern(suffix=".queniuei.com", pattern=r"${domain}.queniuei.com"),
        CNAMEPattern(suffix=".queniues.com", pattern=r"${domain}.queniues.com"),
        CNAMEPattern(suffix=".queniuez.com", pattern=r"${domain}.queniuez.com"),
        CNAMEPattern(suffix=".queniufa.com", pattern=r"${domain}.queniufa.com"),
        CNAMEPattern(suffix=".queniufm.com", pattern=r"${domain}.queniufm.com"),
        CNAMEPattern(suffix=".queniufr.com", pattern=r"${domain}.queniufr.com"),
        CNAMEPattern(suffix=".queniufw.com", pattern=r"${domain}.queniufw.com"),
        CNAMEPattern(suffix=".queniufz.com", pattern=r"${domain}.queniufz.com"),
        CNAMEPattern(suffix=".queniugd.com", pattern=r"${domain}.queniugd.com"),
        CNAMEPattern(suffix=".queniugm.com", pattern=r"${domain}.queniugm.com"),
        CNAMEPattern(suffix=".queniugslb.com", pattern=r"${domain}.queniugslb.com"),
        CNAMEPattern(suffix=".queniugv.com", pattern=r"${domain}.queniugv.com"),
        CNAMEPattern(suffix=".queniugz.com", pattern=r"${domain}.queniugz.com"),
        CNAMEPattern(suffix=".queniuhg.com", pattern=r"${domain}.queniuhg.com"),
        CNAMEPattern(suffix=".queniuhl.com", pattern=r"${domain}.queniuhl.com"),
        CNAMEPattern(suffix=".queniuhx.com", pattern=r"${domain}.queniuhx.com"),
        CNAMEPattern(suffix=".queniuhy.com", pattern=r"${domain}.queniuhy.com"),
        CNAMEPattern(suffix=".queniuhz.com", pattern=r"${domain}.queniuhz.com"),
        CNAMEPattern(suffix=".queniuic.com", pattern=r"${domain}.queniuic.com"),
        CNAMEPattern(suffix=".queniuif.com", pattern=r"${domain}.queniuif.com"),
        CNAMEPattern(suffix=".queniuin.com", pattern=r"${domain}.queniuin.com"),
        CNAMEPattern(suffix=".queniuiq.com", pattern=r"${domain}.queniuiq.com"),
        CNAMEPattern(suffix=".queniuit.com", pattern=r"${domain}.queniuit.com"),
        CNAMEPattern(suffix=".queniuiy.com", pattern=r"${domain}.queniuiy.com"),
        CNAMEPattern(suffix=".queniuja.com", pattern=r"${domain}.queniuja.com"),
        CNAMEPattern(suffix=".queniujd.com", pattern=r"${domain}.queniujd.com"),
        CNAMEPattern(suffix=".queniujf.com", pattern=r"${domain}.queniujf.com"),
        CNAMEPattern(suffix=".queniujg.com", pattern=r"${domain}.queniujg.com"),
        CNAMEPattern(suffix=".queniujq.com", pattern=r"${domain}.queniujq.com"),
        CNAMEPattern(suffix=".queniujz.com", pattern=r"${domain}.queniujz.com"),
        CNAMEPattern(suffix=".queniukk.com", pattern=r"${domain}.queniukk.com"),
        CNAMEPattern(suffix=".queniukq.com", pattern=r"${domain}.queniukq.com"),
        CNAMEPattern(suffix=".queniukr.com", pattern=r"${domain}.queniukr.com"),
        CNAMEPattern(suffix=".queniuks.com", pattern=r"${domain}.queniuks.com"),
        CNAMEPattern(suffix=".queniukt.com", pattern=r"${domain}.queniukt.com"),
        CNAMEPattern(suffix=".queniukw.com", pattern=r"${domain}.queniukw.com"),
        CNAMEPattern(suffix=".queniukx.com", pattern=r"${domain}.queniukx.com"),
        CNAMEPattern(suffix=".queniulf.com", pattern=r"${domain}.queniulf.com"),
        CNAMEPattern(suffix=".queniulg.com", pattern=r"${domain}.queniulg.com"),
        CNAMEPattern(suffix=".queniuli.com", pattern=r"${domain}.queniuli.com"),
        CNAMEPattern(suffix=".queniulp.com", pattern=r"${domain}.queniulp.com"),
        CNAMEPattern(suffix=".queniulr.com", pattern=r"${domain}.queniulr.com"),
        CNAMEPattern(suffix=".queniuls.com", pattern=r"${domain}.queniuls.com"),
        CNAMEPattern(suffix=".queniulv.com", pattern=r"${domain}.queniulv.com"),
        CNAMEPattern(suffix=".queniumd.com", pattern=r"${domain}.queniumd.com"),
        CNAMEPattern(suffix=".queniumf.com", pattern=r"${domain}.queniumf.com"),
        CNAMEPattern(suffix=".queniumn.com", pattern=r"${domain}.queniumn.com"),
        CNAMEPattern(suffix=".queniumo.com", pattern=r"${domain}.queniumo.com"),
        CNAMEPattern(suffix=".queniumy.com", pattern=r"${domain}.queniumy.com"),
        CNAMEPattern(suffix=".queniunh.com", pattern=r"${domain}.queniunh.com"),
        CNAMEPattern(suffix=".queniuni.com", pattern=r"${domain}.queniuni.com"),
        CNAMEPattern(suffix=".queniunq.com", pattern=r"${domain}.queniunq.com"),
        CNAMEPattern(suffix=".queniuns.com", pattern=r"${domain}.queniuns.com"),
        CNAMEPattern(suffix=".queniuny.com", pattern=r"${domain}.queniuny.com"),
        CNAMEPattern(suffix=".queniunz.com", pattern=r"${domain}.queniunz.com"),
        CNAMEPattern(suffix=".queniuod.com", pattern=r"${domain}.queniuod.com"),
        CNAMEPattern(suffix=".queniuog.com", pattern=r"${domain}.queniuog.com"),
        CNAMEPattern(suffix=".queniuop.com", pattern=r"${domain}.queniuop.com"),
        CNAMEPattern(suffix=".queniuos.com", pattern=r"${domain}.queniuos.com"),
        CNAMEPattern(suffix=".queniuot.com", pattern=r"${domain}.queniuot.com"),
        CNAMEPattern(suffix=".queniuoy.com", pattern=r"${domain}.queniuoy.com"),
        CNAMEPattern(suffix=".queniupc.com", pattern=r"${domain}.queniupc.com"),
        CNAMEPattern(suffix=".queniupe.com", pattern=r"${domain}.queniupe.com"),
        CNAMEPattern(suffix=".queniupg.com", pattern=r"${domain}.queniupg.com"),
        CNAMEPattern(suffix=".queniupj.com", pattern=r"${domain}.queniupj.com"),
        CNAMEPattern(suffix=".queniupl.com", pattern=r"${domain}.queniupl.com"),
        CNAMEPattern(suffix=".queniupq.com", pattern=r"${domain}.queniupq.com"),
        CNAMEPattern(suffix=".queniupz.com", pattern=r"${domain}.queniupz.com"),
        CNAMEPattern(suffix=".queniuqe.com", pattern=r"${domain}.queniuqe.com"),
        CNAMEPattern(suffix=".queniuql.com", pattern=r"${domain}.queniuql.com"),
        CNAMEPattern(suffix=".queniuqm.com", pattern=r"${domain}.queniuqm.com"),
        CNAMEPattern(suffix=".queniuqt.com", pattern=r"${domain}.queniuqt.com"),
        CNAMEPattern(suffix=".queniuqy.com", pattern=r"${domain}.queniuqy.com"),
        CNAMEPattern(suffix=".queniuqz.com", pattern=r"${domain}.queniuqz.com"),
        CNAMEPattern(suffix=".queniurc.com", pattern=r"${domain}.queniurc.com"),
        CNAMEPattern(suffix=".queniurj.com", pattern=r"${domain}.queniurj.com"),
        CNAMEPattern(suffix=".queniurk.com", pattern=r"${domain}.queniurk.com"),
        CNAMEPattern(suffix=".queniurq.com", pattern=r"${domain}.queniurq.com"),
        CNAMEPattern(suffix=".queniuru.com", pattern=r"${domain}.queniuru.com"),
        CNAMEPattern(suffix=".queniurv.com", pattern=r"${domain}.queniurv.com"),
        CNAMEPattern(suffix=".queniurx.com", pattern=r"${domain}.queniurx.com"),
        CNAMEPattern(suffix=".queniusa.com", pattern=r"${domain}.queniusa.com"),
        CNAMEPattern(suffix=".queniusf.com", pattern=r"${domain}.queniusf.com"),
        CNAMEPattern(suffix=".queniusg.com", pattern=r"${domain}.queniusg.com"),
        CNAMEPattern(suffix=".queniusi.com", pattern=r"${domain}.queniusi.com"),
        CNAMEPattern(suffix=".queniuso.com", pattern=r"${domain}.queniuso.com"),
        CNAMEPattern(suffix=".queniusp.com", pattern=r"${domain}.queniusp.com"),
        CNAMEPattern(suffix=".queniusr.com", pattern=r"${domain}.queniusr.com"),
        CNAMEPattern(suffix=".queniusy.com", pattern=r"${domain}.queniusy.com"),
        CNAMEPattern(suffix=".queniusz.com", pattern=r"${domain}.queniusz.com"),
        CNAMEPattern(suffix=".queniutc.com", pattern=r"${domain}.queniutc.com"),
        CNAMEPattern(suffix=".queniutn.com", pattern=r"${domain}.queniutn.com"),
        CNAMEPattern(suffix=".queniutt.com", pattern=r"${domain}.queniutt.com"),
        CNAMEPattern(suffix=".queniutz.com", pattern=r"${domain}.queniutz.com"),
        CNAMEPattern(suffix=".queniuua.com", pattern=r"${domain}.queniuua.com"),
        CNAMEPattern(suffix=".queniuuc.com", pattern=r"${domain}.queniuuc.com"),
        CNAMEPattern(suffix=".queniuuf.com", pattern=r"${domain}.queniuuf.com"),
        CNAMEPattern(suffix=".queniuuk.com", pattern=r"${domain}.queniuuk.com"),
        CNAMEPattern(suffix=".queniuum.com", pattern=r"${domain}.queniuum.com"),
        CNAMEPattern(suffix=".queniuuq.com", pattern=r"${domain}.queniuuq.com"),
        CNAMEPattern(suffix=".queniuus.com", pattern=r"${domain}.queniuus.com"),
        CNAMEPattern(suffix=".queniuuy.com", pattern=r"${domain}.queniuuy.com"),
        CNAMEPattern(suffix=".queniuvb.com", pattern=r"${domain}.queniuvb.com"),
        CNAMEPattern(suffix=".queniuvc.com", pattern=r"${domain}.queniuvc.com"),
        CNAMEPattern(suffix=".queniuvi.com", pattern=r"${domain}.queniuvi.com"),
        CNAMEPattern(suffix=".queniuvk.com", pattern=r"${domain}.queniuvk.com"),
        CNAMEPattern(suffix=".queniuvq.com", pattern=r"${domain}.queniuvq.com"),
        CNAMEPattern(suffix=".queniuvu.com", pattern=r"${domain}.queniuvu.com"),
        CNAMEPattern(suffix=".queniuvx.com", pattern=r"${domain}.queniuvx.com"),
        CNAMEPattern(suffix=".queniuwb.com", pattern=r"${domain}.queniuwb.com"),
        CNAMEPattern(suffix=".queniuwh.com", pattern=r"${domain}.queniuwh.com"),
        CNAMEPattern(suffix=".queniuwk.com", pattern=r"${domain}.queniuwk.com"),
        CNAMEPattern(suffix=".queniuwx.com", pattern=r"${domain}.queniuwx.com"),
        CNAMEPattern(suffix=".queniuxk.com", pattern=r"${domain}.queniuxk.com"),
        CNAMEPattern(suffix=".queniuxr.com", pattern=r"${domain}.queniuxr.com"),
        CNAMEPattern(suffix=".queniuxx.com", pattern=r"${domain}.queniuxx.com"),
        CNAMEPattern(suffix=".queniuyb.com", pattern=r"${domain}.queniuyb.com"),
        CNAMEPattern(suffix=".queniuyg.com", pattern=r"${domain}.queniuyg.com"),
        CNAMEPattern(suffix=".queniuyk.com", pattern=r"${domain}.queniuyk.com"),
        CNAMEPattern(suffix=".queniuys.com", pattern=r"${domain}.queniuys.com"),
        CNAMEPattern(suffix=".queniuyu.com", pattern=r"${domain}.queniuyu.com"),
        CNAMEPattern(suffix=".queniuyz.com", pattern=r"${domain}.queniuyz.com"),
        CNAMEPattern(suffix=".queniuza.com", pattern=r"${domain}.queniuza.com"),
        CNAMEPattern(suffix=".queniuzd.com", pattern=r"${domain}.queniuzd.com"),
        CNAMEPattern(suffix=".queniuzf.com", pattern=r"${domain}.queniuzf.com"),
        CNAMEPattern(suffix=".queniuzl.com", pattern=r"${domain}.queniuzl.com"),
        CNAMEPattern(suffix=".queniuzp.com", pattern=r"${domain}.queniuzp.com"),
        CNAMEPattern(suffix=".queniuzv.com", pattern=r"${domain}.queniuzv.com"),
        CNAMEPattern(suffix=".queniuzy.com", pattern=r"${domain}.queniuzy.com"),
        CNAMEPattern(suffix=".queniuzz.com", pattern=r"${domain}.queniuzz.com"),
    ],
    cidr=BGPViewCIDR(["alibaba", "taobao", "alicloud"]),
)
