from cdnmon.model.cdn import BGPViewCIDR
from cdnmon.model.cdn import CNAMEPattern
from cdnmon.model.cdn import CommonCDN

CDN = CommonCDN(
    name="huawei",
    asn_patterns=["huawei", "futurewei"],
    cname_suffixes=[
        CNAMEPattern(suffix=".cdnhwc1.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc1.cn"),
        CNAMEPattern(suffix=".cdnhwc1.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc1.com"),
        CNAMEPattern(suffix=".cdnhwc2.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc2.cn"),
        CNAMEPattern(suffix=".cdnhwc2.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc2.com"),
        CNAMEPattern(suffix=".cdnhwc22.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc22.com"),
        CNAMEPattern(suffix=".cdnhwc3.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc3.cn"),
        CNAMEPattern(suffix=".cdnhwc3.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc3.com"),
        CNAMEPattern(suffix=".cdnhwc4.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc4.cn"),
        CNAMEPattern(suffix=".cdnhwc4.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc4.com"),
        CNAMEPattern(suffix=".cdnhwc5.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc5.cn"),
        CNAMEPattern(suffix=".cdnhwc5.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc5.com"),
        CNAMEPattern(suffix=".cdnhwc6.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc6.cn"),
        CNAMEPattern(suffix=".cdnhwc6.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc6.com"),
        CNAMEPattern(suffix=".cdnhwc7.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc7.cn"),
        CNAMEPattern(suffix=".cdnhwc7.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc7.com"),
        CNAMEPattern(suffix=".cdnhwc8.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc8.cn"),
        CNAMEPattern(suffix=".cdnhwc8.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc8.com"),
        CNAMEPattern(suffix=".cdnhwc9.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc9.cn"),
        CNAMEPattern(suffix=".cdnhwc9.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc9.com"),
        CNAMEPattern(suffix=".cdnhwc10.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc10.cn"),
        CNAMEPattern(suffix=".cdnhwc10.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwc10.com"),
        CNAMEPattern(suffix=".cdnhwcaip122.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcaip122.cn"),
        CNAMEPattern(suffix=".cdnhwcajk17.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcajk17.com"),
        CNAMEPattern(suffix=".cdnhwcaoc115.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcaoc115.cn"),
        CNAMEPattern(suffix=".cdnhwcatq08.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcatq08.com"),
        CNAMEPattern(suffix=".cdnhwcbie120.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcbie120.cn"),
        CNAMEPattern(suffix=".cdnhwcbni108.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcbni108.com"),
        CNAMEPattern(suffix=".cdnhwcbqs106.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcbqs106.com"),
        CNAMEPattern(suffix=".cdnhwcbvo20.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcbvo20.cn"),
        CNAMEPattern(suffix=".cdnhwcbzj102.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcbzj102.com"),
        CNAMEPattern(suffix=".cdnhwcchh18.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcchh18.com"),
        CNAMEPattern(suffix=".cdnhwccmz121.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwccmz121.com"),
        CNAMEPattern(suffix=".cdnhwccvo19.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwccvo19.cn"),
        CNAMEPattern(suffix=".cdnhwcdkd21.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcdkd21.cn"),
        CNAMEPattern(suffix=".cdnhwcdvg22.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcdvg22.cn"),
        CNAMEPattern(suffix=".cdnhwcead111.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcead111.com"),
        CNAMEPattern(suffix=".cdnhwcedi10.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcedi10.com"),
        CNAMEPattern(suffix=".cdnhwcedt124.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcedt124.com"),
        CNAMEPattern(suffix=".cdnhwceft18.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwceft18.cn"),
        CNAMEPattern(suffix=".cdnhwceod109.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwceod109.cn"),
        CNAMEPattern(suffix=".cdnhwcfzp15.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcfzp15.cn"),
        CNAMEPattern(suffix=".cdnhwcggk22.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcggk22.com"),
        CNAMEPattern(suffix=".cdnhwcgnc118.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcgnc118.com"),
        CNAMEPattern(suffix=".cdnhwcgqa21.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcgqa21.com"),
        CNAMEPattern(suffix=".cdnhwcgqs21.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcgqs21.com"),
        CNAMEPattern(suffix=".cdnhwcgrb01.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcgrb01.cn"),
        CNAMEPattern(suffix=".cdnhwcgvs16.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcgvs16.cn"),
        CNAMEPattern(suffix=".cdnhwchcg02.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwchcg02.com"),
        CNAMEPattern(suffix=".cdnhwcibv122.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcibv122.com"),
        CNAMEPattern(suffix=".cdnhwcick110.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcick110.com"),
        CNAMEPattern(suffix=".cdnhwcidu117.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcidu117.cn"),
        CNAMEPattern(suffix=".cdnhwcjbj05.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcjbj05.cn"),
        CNAMEPattern(suffix=".cdnhwcjkl10.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcjkl10.cn"),
        CNAMEPattern(suffix=".cdnhwcjlg112.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcjlg112.com"),
        CNAMEPattern(suffix=".cdnhwcjog12.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcjog12.com"),
        CNAMEPattern(suffix=".cdnhwcjqv17.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcjqv17.cn"),
        CNAMEPattern(suffix=".cdnhwcjsb120.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcjsb120.com"),
        CNAMEPattern(suffix=".cdnhwckbw08.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwckbw08.cn"),
        CNAMEPattern(suffix=".cdnhwckfd24.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwckfd24.cn"),
        CNAMEPattern(suffix=".cdnhwckfz116.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwckfz116.com"),
        CNAMEPattern(suffix=".cdnhwckon103.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwckon103.com"),
        CNAMEPattern(suffix=".cdnhwcljk104.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcljk104.com"),
        CNAMEPattern(suffix=".cdnhwclkl04.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwclkl04.cn"),
        CNAMEPattern(suffix=".cdnhwcllh11.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcllh11.com"),
        CNAMEPattern(suffix=".cdnhwclnh23.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwclnh23.cn"),
        CNAMEPattern(suffix=".cdnhwclrd102.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwclrd102.cn"),
        CNAMEPattern(suffix=".cdnhwclsl119.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwclsl119.cn"),
        CNAMEPattern(suffix=".cdnhwclxu105.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwclxu105.com"),
        CNAMEPattern(suffix=".cdnhwclxw05.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwclxw05.com"),
        CNAMEPattern(suffix=".cdnhwcoem01.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcoem01.com"),
        CNAMEPattern(suffix=".cdnhwcofl101.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcofl101.cn"),
        CNAMEPattern(suffix=".cdnhwcogx108.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcogx108.cn"),
        CNAMEPattern(suffix=".cdnhwcohm19.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcohm19.com"),
        CNAMEPattern(suffix=".cdnhwcojn124.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcojn124.cn"),
        CNAMEPattern(suffix=".cdnhwconz06.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwconz06.cn"),
        CNAMEPattern(suffix=".cdnhwcoph123.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcoph123.com"),
        CNAMEPattern(suffix=".cdnhwcozb112.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcozb112.cn"),
        CNAMEPattern(suffix=".cdnhwcpcw110.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcpcw110.cn"),
        CNAMEPattern(suffix=".cdnhwcpqh13.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcpqh13.cn"),
        CNAMEPattern(suffix=".cdnhwcprh113.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcprh113.com"),
        CNAMEPattern(suffix=".cdnhwcpsd13.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcpsd13.com"),
        CNAMEPattern(suffix=".cdnhwcqgw115.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcqgw115.com"),
        CNAMEPattern(suffix=".cdnhwcqir15.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcqir15.com"),
        CNAMEPattern(suffix=".cdnhwcqrr114.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcqrr114.cn"),
        CNAMEPattern(suffix=".cdnhwcqve117.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcqve117.com"),
        CNAMEPattern(suffix=".cdnhwcqvk105.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcqvk105.cn"),
        CNAMEPattern(suffix=".cdnhwcqwg14.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcqwg14.com"),
        CNAMEPattern(suffix=".cdnhwcrgg07.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcrgg07.cn"),
        CNAMEPattern(suffix=".cdnhwcrpp12.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcrpp12.cn"),
        CNAMEPattern(suffix=".cdnhwcscc123.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcscc123.cn"),
        CNAMEPattern(suffix=".cdnhwcsjs09.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcsjs09.cn"),
        CNAMEPattern(suffix=".cdnhwcsux118.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcsux118.cn"),
        CNAMEPattern(suffix=".cdnhwctmz11.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwctmz11.cn"),
        CNAMEPattern(suffix=".cdnhwctnm107.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwctnm107.com"),
        CNAMEPattern(suffix=".cdnhwctxz24.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwctxz24.com"),
        CNAMEPattern(suffix=".cdnhwctyd116.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwctyd116.cn"),
        CNAMEPattern(suffix=".cdnhwcuim119.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcuim119.com"),
        CNAMEPattern(suffix=".cdnhwcupf06.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcupf06.com"),
        CNAMEPattern(suffix=".cdnhwcurq03.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcurq03.com"),
        CNAMEPattern(suffix=".cdnhwcurr103.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcurr103.cn"),
        CNAMEPattern(suffix=".cdnhwcuwd107.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcuwd107.cn"),
        CNAMEPattern(suffix=".cdnhwcuxc121.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcuxc121.cn"),
        CNAMEPattern(suffix=".cdnhwcvix16.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcvix16.com"),
        CNAMEPattern(suffix=".cdnhwcwqz113.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcwqz113.cn"),
        CNAMEPattern(suffix=".cdnhwcxcy07.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcxcy07.com"),
        CNAMEPattern(suffix=".cdnhwcxsi14.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcxsi14.cn"),
        CNAMEPattern(suffix=".cdnhwcywp03.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcywp03.cn"),
        CNAMEPattern(suffix=".cdnhwcyxb02.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcyxb02.cn"),
        CNAMEPattern(suffix=".cdnhwczba04.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwczba04.com"),
        CNAMEPattern(suffix=".cdnhwczic111.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwczic111.cn"),
        CNAMEPattern(suffix=".cdnhwczid104.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwczid104.cn"),
        CNAMEPattern(suffix=".cdnhwczjt20.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwczjt20.com"),
        CNAMEPattern(suffix=".cdnhwczks109.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwczks109.com"),
        CNAMEPattern(suffix=".cdnhwczmn114.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwczmn114.com"),
        CNAMEPattern(suffix=".cdnhwczoy106.cn", pattern=r"${domain}.[0-9a-f]{8}.cdnhwczoy106.cn"),
        CNAMEPattern(suffix=".cdnhwczth23.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwczth23.com"),
        CNAMEPattern(suffix=".cdnhwcztu09.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwcztu09.com"),
        CNAMEPattern(suffix=".cdnhwczxh101.com", pattern=r"${domain}.[0-9a-f]{8}.cdnhwczxh101.com"),
    ],
    cidr=BGPViewCIDR(["huawei", "futurewei"]),
)
